{
 "metadata": {
  "name": ""
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "# Additional tips and tricks for designing networks\n",
      "\n",
      "This tutorial assumes that you have read\n",
      "the `network_design` tutorial,\n",
      "and have designed a network or two.\n",
      "Here, we will give a few advanced tips and tricks\n",
      "for designing networks that can be reused flexibly.\n",
      "In particular, these tips will use the\n",
      "`config` system, so we will also assume that\n",
      "you have gone over the `config` tutorial.\n",
      "\n",
      "Briefly, the general principles covered\n",
      "in this tutorial are\n",
      "\n",
      "0. Accept a network argument\n",
      "0. Accept a config argument for groups of parameters\n",
      "\n",
      "We will demonstrate these principles\n",
      "using the two examples from the `network_design` tutorial."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "import numpy as np\n",
      "import matplotlib.pyplot as plt\n",
      "%matplotlib inline\n",
      "\n",
      "import nengo\n",
      "%load_ext nengo.ipynb\n",
      "from nengo.dists import Choice\n",
      "from nengo.utils.functions import piecewise\n",
      "from nengo.utils.ipython import hide_input\n",
      "def test_integrators(net):\n",
      "    with net:\n",
      "        piecewise_f = piecewise({0: 0, 0.2: 0.5, 1: 0, 2: -1, 3: 0, 4: 1, 5: 0})\n",
      "        piecewise_inp = nengo.Node(piecewise_f)\n",
      "        nengo.Connection(piecewise_inp, net.pre_integrator.input)\n",
      "        input_probe = nengo.Probe(piecewise_inp)\n",
      "        pre_probe = nengo.Probe(net.pre_integrator.ensemble, synapse=0.01)\n",
      "        post_probe = nengo.Probe(net.post_integrator.ensemble, synapse=0.01)\n",
      "    with nengo.Simulator(net) as sim:\n",
      "        sim.run(6)\n",
      "    plt.plot(sim.trange(), sim.data[input_probe], color='k')\n",
      "    plt.plot(sim.trange(), sim.data[pre_probe], color='b')\n",
      "    plt.plot(sim.trange(), sim.data[post_probe], color='g')\n",
      "hide_input()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "text": [
        "<IPython.core.display.Javascript at 0x7f31bdf6a0d0>"
       ]
      },
      {
       "html": [
        "\n",
        "        <a id=\"492104780\" href=\"javascript:toggle_input_492104780()\"\n",
        "          >Show Input</a>\n",
        "\n",
        "        <script type=\"text/javascript\">\n",
        "        var toggle_input_492104780;\n",
        "        (function() {\n",
        "            if (typeof jQuery == 'undefined') {\n",
        "                // no jQuery\n",
        "                var link_492104780 = document.getElementById(\"492104780\");\n",
        "                var cell = link_492104780;\n",
        "                while (cell.className.split(' ')[0] != \"cell\") {\n",
        "                    cell = cell.parentNode;\n",
        "                }\n",
        "                var input_492104780;\n",
        "                for (var i = 0; i < cell.children.length; i++) {\n",
        "                    if (cell.children[i].className.split(' ')[0] == \"input\")\n",
        "                        input_492104780 = cell.children[i];\n",
        "                }\n",
        "                input_492104780.style.display = \"none\"; // hide\n",
        "\n",
        "                toggle_input_492104780 = function() {\n",
        "                    if (input_492104780.style.display == \"none\") {\n",
        "                        input_492104780.style.display = \"\"; // show\n",
        "                        link_492104780.innerHTML = \"Hide Input\";\n",
        "                    } else {\n",
        "                        input_492104780.style.display = \"none\"; // hide\n",
        "                        link_492104780.innerHTML = \"Show Input\";\n",
        "                    }\n",
        "                }\n",
        "\n",
        "            } else {\n",
        "                // jQuery\n",
        "                var link_492104780 = $(\"a[id='492104780']\");\n",
        "                var cell_492104780 = link_492104780.parents(\"div.cell:first\");\n",
        "                var input_492104780 = cell_492104780.children(\"div.input\");\n",
        "                input_492104780.hide();\n",
        "\n",
        "                toggle_input_492104780 = function() {\n",
        "                    if (input_492104780.is(':hidden')) {\n",
        "                        input_492104780.slideDown();\n",
        "                        link_492104780[0].innerHTML = \"Hide Input\";\n",
        "                    } else {\n",
        "                        input_492104780.slideUp();\n",
        "                        link_492104780[0].innerHTML = \"Show Input\";\n",
        "                    }\n",
        "                }\n",
        "            }\n",
        "        }());\n",
        "        </script>\n",
        "    "
       ],
       "output_type": "pyout",
       "prompt_number": 1,
       "text": [
        "<IPython.core.display.HTML at 0x7f3186138d10>"
       ]
      }
     ],
     "prompt_number": 1
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## 1. Accept a network argument\n",
      "\n",
      "Typically, a network-creation function\n",
      "will take a set of arguments,\n",
      "which affect some important parts\n",
      "of the network.\n",
      "When testing the network,\n",
      "it's common to change several parameters\n",
      "to see how they affect the network.\n",
      "One way to do this is to add more and more\n",
      "arguments to your function;\n",
      "this quickly gets out of hand.\n",
      "Instead, use the `config` system,\n",
      "which  enables us to set\n",
      "network-level defaults for all Nengo objects.\n",
      "\n",
      "You can either do this by creating your network\n",
      "in the context of some other network,\n",
      "or you can modify your function\n",
      "to optionally take in a network instance,\n",
      "which you will build your objects into.\n",
      "\n",
      "In the example below,\n",
      "we change both integrators to use `LIFRate` neurons\n",
      "by changing the `config` object\n",
      "in the network both integrators\n",
      "are build within.\n",
      "We also change the `post_integrator`\n",
      "to use a very small radius\n",
      "by passing in a network\n",
      "which has its default radius modified."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def Integrator(n_neurons, dimensions, tau=0.1, net=None):\n",
      "    if net is None:\n",
      "        net = nengo.Network()\n",
      "    with net:\n",
      "        net.input = nengo.Node(size_in=dimensions)\n",
      "        net.ensemble = nengo.Ensemble(n_neurons, dimensions=dimensions)\n",
      "        nengo.Connection(net.ensemble, net.ensemble, synapse=tau)\n",
      "        nengo.Connection(net.input, net.ensemble,\n",
      "                         synapse=None, transform=tau)\n",
      "    return net\n",
      "\n",
      "net = nengo.Network(label=\"Two integrators\")\n",
      "with net:\n",
      "    # Make both integrators use LIFRate neurons\n",
      "    net.config[nengo.Ensemble].neuron_type = nengo.LIFRate()\n",
      "    net.pre_integrator = Integrator(50, 1)\n",
      "    # Lower the radius of the post_integrator\n",
      "    net.post_integrator = nengo.Network()\n",
      "    net.post_integrator.config[nengo.Ensemble].radius = 0.2\n",
      "    Integrator(50, 1, net=net.post_integrator)\n",
      "    nengo.Connection(net.pre_integrator.ensemble, net.post_integrator.input)\n",
      "test_integrators(net)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAEACAYAAACwB81wAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nSOALIUSQkMAXQoggIYEvhBBB4v8DoOIJ5rffwvkAAAAASUVORK5CYII=\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f318614c1d0>"
       ]
      }
     ],
     "prompt_number": 2
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## 2. Accept a config argument for groups of parameters\n",
      "\n",
      "Often, you will not want to use the\n",
      "network-level defaults for all of your objects.\n",
      "Some objects need certain things overwritten,\n",
      "while others need other values overwritten.\n",
      "Again, it is possible to deal with this issue\n",
      "by adding more and more parameters,\n",
      "but this quickly gets out of hand.\n",
      "Instead, add a small number of arguments\n",
      "that optionally accept a `config` object,\n",
      "which allows for setting multiple parameters at once.\n",
      "\n",
      "In the coupled integrator network example,\n",
      "we make two connections.\n",
      "We have to be careful changing the defaults\n",
      "for those connections, as they are wildly different;\n",
      "one is a recurrent connection from an ensemble to itself,\n",
      "while the other is a connection from a node to an ensemble.\n",
      "We will accept a `config` object for the recurrent connection\n",
      "to make this easier."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def Integrator(n_neurons, dimensions, recurrent_config=None, net=None):\n",
      "    if net is None:\n",
      "        net = nengo.Network()\n",
      "    if recurrent_config is None:\n",
      "        recurrent_config = nengo.Config(nengo.Connection)\n",
      "        recurrent_config[nengo.Connection].synapse = nengo.Lowpass(0.1)\n",
      "    with net:\n",
      "        net.input = nengo.Node(size_in=dimensions)\n",
      "        net.ensemble = nengo.Ensemble(n_neurons, dimensions=dimensions)\n",
      "        with recurrent_config:\n",
      "            nengo.Connection(net.ensemble, net.ensemble)\n",
      "            tau = nengo.Config.default(nengo.Connection, 'synapse').tau\n",
      "        nengo.Connection(net.input, net.ensemble,\n",
      "                         synapse=None, transform=tau)\n",
      "    return net\n",
      "\n",
      "net = nengo.Network(label=\"Two integrators\")\n",
      "with net:\n",
      "    # Make both integrators use LIFRate neurons\n",
      "    net.config[nengo.Ensemble].neuron_type = nengo.LIFRate()\n",
      "    net.pre_integrator = Integrator(50, 1)\n",
      "    # Give the post_integrator a shorter tau (should make integration fail)\n",
      "    recurrent_config = nengo.Config(nengo.Connection)\n",
      "    recurrent_config[nengo.Connection].synapse = nengo.Lowpass(0.01)\n",
      "    net.post_integrator = Integrator(50, 1, recurrent_config=recurrent_config)\n",
      "    nengo.Connection(net.pre_integrator.ensemble, net.post_integrator.input)\n",
      "test_integrators(net)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAEACAYAAACwB81wAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f3182fb69d0>"
       ]
      }
     ],
     "prompt_number": 3
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## Longer example: double integrator network\n",
      "\n",
      "Recall in the previous tutorial that\n",
      "we created a model\n",
      "that released a lever 0.6 to 1.0 seconds\n",
      "after pressing a lever.\n",
      "Let's use the above principles,\n",
      "and the `config` system in general,\n",
      "to improve the code constructing this model."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def controlled_integrator(n_neurons, dimensions, recurrent_config=None, net=None):\n",
      "    if net is None:\n",
      "        net = nengo.Network()\n",
      "    if recurrent_config is None:\n",
      "        recurrent_config = nengo.Config(nengo.Connection)\n",
      "        recurrent_config[nengo.Connection].synapse = nengo.Lowpass(0.1)\n",
      "    with net:\n",
      "        net.ensemble = nengo.Ensemble(n_neurons, dimensions=dimensions + 1)\n",
      "        with recurrent_config:\n",
      "            nengo.Connection(net.ensemble, net.ensemble[:dimensions],\n",
      "                             function=lambda x: x[:-1] * (1.0 - x[-1]))\n",
      "    return net\n",
      "\n",
      "def medial_pfc(coupling_strength, n_neurons_per_integrator=200, recurrent_config=None, tau=0.1, net=None):\n",
      "    if net is None:\n",
      "        net = nengo.Network()\n",
      "    with net:\n",
      "        recurrent_config = nengo.Config(nengo.Connection)\n",
      "        recurrent_config[nengo.Connection].synapse = nengo.Lowpass(tau)\n",
      "        net.pre = controlled_integrator(n_neurons_per_integrator, 1, recurrent_config)\n",
      "        net.post = controlled_integrator(n_neurons_per_integrator, 1, recurrent_config)\n",
      "        nengo.Connection(net.pre.ensemble[0], net.post.ensemble[0],\n",
      "                         transform=coupling_strength)\n",
      "    return net\n",
      "\n",
      "def motor_cortex(command_threshold, n_neurons_per_command=30, ens_config=None, net=None):\n",
      "    if net is None:\n",
      "        net = nengo.Network()\n",
      "    if ens_config is None:\n",
      "        ens_config = nengo.Config(nengo.Ensemble)\n",
      "        ens_config[nengo.Ensemble].encoders = Choice([[1]])\n",
      "        ens_config[nengo.Ensemble].intercepts = Choice([command_threshold])\n",
      "    with net:\n",
      "        with ens_config:\n",
      "            net.press = nengo.Ensemble(n_neurons_per_command, dimensions=1)\n",
      "            net.release = nengo.Ensemble(n_neurons_per_command, dimensions=1)\n",
      "    return net\n",
      "\n",
      "def double_integrator(mpfc_coupling_strength,\n",
      "                      command_threshold,\n",
      "                      press_to_pre_gain=3,\n",
      "                      press_to_post_control=-6,\n",
      "                      recurrent_tau=0.1,\n",
      "                      net=None):\n",
      "    if net is None:\n",
      "        net = nengo.Network()\n",
      "    with net:\n",
      "        net.mpfc = medial_pfc(mpfc_coupling_strength)\n",
      "        net.motor = motor_cortex(command_threshold)\n",
      "        nengo.Connection(net.motor.press, net.mpfc.pre.ensemble[0],\n",
      "                         transform=recurrent_tau * press_to_pre_gain)\n",
      "        nengo.Connection(net.motor.press, net.mpfc.post.ensemble[1],\n",
      "                         transform=press_to_post_control)\n",
      "        nengo.Connection(net.mpfc.post.ensemble[0], net.motor.release)\n",
      "    return net\n",
      "    \n",
      "def test_doubleintegrator(net):\n",
      "    # Provide input and probe outside of network construction, for more flexibility\n",
      "    with net:\n",
      "        nengo.Connection(nengo.Node(lambda t: 1 if t < 0.2 else 0), net.motor.press)\n",
      "        pr_press = nengo.Probe(net.motor.press, synapse=0.01)\n",
      "        pr_release = nengo.Probe(net.motor.release, synapse=0.01)\n",
      "        pr_pre_int = nengo.Probe(net.mpfc.pre.ensemble[0], synapse=0.01)\n",
      "        pr_post_int = nengo.Probe(net.mpfc.post.ensemble[0], synapse=0.01)\n",
      "    with nengo.Simulator(net) as sim:\n",
      "        sim.run(1.4)\n",
      "    t = sim.trange()\n",
      "    plt.figure()\n",
      "    plt.subplot(2, 1, 1)\n",
      "    plt.plot(t, sim.data[pr_press], c='b', label=\"Press\")\n",
      "    plt.plot(t, sim.data[pr_release], c='g', label=\"Release\")\n",
      "    plt.axvspan(0, 0.2, color='b', alpha=0.3)\n",
      "    plt.axvspan(0.8, 1.2, color='g', alpha=0.3)\n",
      "    plt.xlim(right=1.4)\n",
      "    plt.legend(loc=\"best\")\n",
      "    plt.subplot(2, 1, 2)\n",
      "    plt.plot(t, sim.data[pr_pre_int], label=\"Pre Integrator\")\n",
      "    plt.plot(t, sim.data[pr_post_int], label=\"Post Integrator\")\n",
      "    plt.xlim(right=1.4)\n",
      "    plt.legend(loc=\"best\")\n",
      "\n",
      "for coupling_strength in (0.11, 0.16, 0.21):\n",
      "    net = nengo.Network(seed=0)  # Set seed here instead\n",
      "    # Try the same network with LIFRate neurons\n",
      "    net.config[nengo.Ensemble].neuron_type = nengo.LIFRate()\n",
      "    net = double_integrator(mpfc_coupling_strength=coupling_strength,\n",
      "                            command_threshold=0.85,\n",
      "                            net = net)\n",
      "    test_doubleintegrator(net)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYEAAAEACAYAAABVtcpZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f3182ef8b50>"
       ]
      },
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYEAAAEACAYAAABVtcpZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\nAAALEgAACxIB0t1+/AAAIABJREFUeJzt3Xl8VOX1+PHPk5BAErISIGEL+yIiqBVQEVk0gCBQd1QE\ntVRRtGD5/tQqBSpWUVttVVxa3KrWnUVkLQiKgqDIKglL2BIQQkJIQvbk/P64kxBClkkymTuTnPfr\nNa/cmXnm3pNJ5p6597nPeYyIoJRSqmHysTsApZRS9tEkoJRSDZgmAaWUasA0CSilVAOmSUAppRow\nTQJKKdWAuSQJGGPmG2OOG2O2V9HuMmNMgTHmBldsVymlVO246kjgbWBYZQ2MMT7As8ByF21TKaVU\nLbkkCYjIeuBUFc0eAj4DTrhim0oppWrPLX0CxphWwFjgdcC4Y5tKKaWq5q6O4ZeAR+VsjQpNBEop\n5QEauWk7vwE+MsYYIBIYYYzJF5HFpRsZY7SQkVJK1YCI1OjLtSuTgKGCb/gi0rGkkTFvA1+WTQDF\nFi/23jzw+uuz+OqrWXaHUWOzZs1i1qxZdodRY94e/8hJI7l/+v12h1FjH778Ibc/dLvdYdTI6y+8\nzlf/+sruMGrM+n5dMy5JAsaYD4FBQDNjzGFgJuAPiIi8Waa59+7llVKqnnFJEhARp9O/iNzjim0q\npZSqPR0x7EJduw6yO4RaGTRokN0h1Iq3x9/10q52h1Arvfr2sjuEGvP297423NUx3CBoErCXt8fv\n7TuiXv00CbhafmE+2QXZZOdnk12QTU5BDrkFueQV5pFbmFuyXBuaBJRSqhZyCnJIz00nIzeDzLxM\nMvIyyMjNqPBnZn5myU69sp85BTkABPgFENAogAC/AJo0akJj38Y0btQYf1//kuXa0CSglFIOOQU5\nHM88zvEzxzmZdZKUrBTrZ3YKKVkp1s/slJLnUrJTKJIiQhqHEOwfTHDjYJr6Ny1ZDvYPLlluFtCM\n9mHtCfILOmfHXtlPP18/p+I2d9p8dZBSSnmy/MJ8TmadJDkrmZSsFE7lnLJu2dbP5KxknljzBJl5\nmbRs2pKoplFEBkbSLKAZzQKaERkYSa+Wvaz7gc3OPhfYjEC/QLt/vVrRJKCU8npFUkRKVgpHM46S\nlJHEiTMnSM5KJvlMMieyTpCem054k3CaBzWneWBzwpuEExEQQcfwjoQ3CSevMI+p/acSHhCOj2lY\n18u4apzAfGAUcFxELirn+duBR7HGCGQCk0Vkhyu2rZRqOAqLCknKSOLAqQMcST9SstM/mnGUIL8g\nWgW3olVwK1oEteA3rX5Di8AWtAhqQURABL4+vhWuNzE9kWaBzdz4m3gOVx0JvA28DLxXwfMJwEAR\nOW2MGQ78C+jvom0rpeqh/MJ8EtIS2Juyl4NpB0lIS+DI6SM0C7TOrbcLaUe/1v1oHdKaVsGtvP60\njF1cNVhsvTEmppLnN5a6uxFo7YrtViQ3FzIzrZ+5uZCfD0VFxbFYt7LLxfdrIyOjdq9XqiHLyM1g\nV/Iu4k7GEXcyjoS0BKKbRtMlogsdwztyTcdriAmNIcAvwO5Q6xU7+gR+Byxz5Qr37YN162D3bjh2\nzNrxN20K/v7QuDH4+YGP4zSfMdatvOXSP2vil19g9mxru0qpyhUUFRB/Mp6ff/2Zrb9u5Uj6EbpH\ndqdHZA/GXTiOLs266Ld7N3BrEjDGDAbuBgZU1ObDD2eVLPfqNYhevQZVuL7UVHjlFTh8GIYMgYkT\noU0bCA2t3c68pm65BXJyNAkoVZH8wny2/rqV9UfWs/noZloGtaRPVB8m9J5A98juTl8S2dCtXbuW\ntWvXumRdbksCxpiLgDeB4SJS4Sxkt98+y6n1nTwJf/oTDBwIjz9ufdu3m5+flQRCQuyORCnPISLs\nPrmbVQmr2Ji4kfZh7bmy7ZXcddFdDbYztrYGDRp0zgj52bNn13hdbiklbYxpB3wOjBeR/bXdUGEh\n/P3vMHgwjBtX27W5TnESUEpBbkEuqxJWsWzfMoqkiNhOsYy/aDwRARF2h6ZKcVcp6RlABDDPMbFM\nvoj0ren2Vq+GggLr9IsnadRIk4BSWflZLNmzhC/3fEmP5j2Y/JvJ9Gzes1Y171XdcUspaRGZBExy\nxbYKC+HTT2HqVPCt+LJfW+iRgGrICosKWX1gNR/s+ICLWl7E00Oepl1oO7vDUlXwuhHD27ZBcDD0\n7Gl3JOfTJKAaqsT0RF7c+CKNfBoxY+AMOkd0tjsk5SSvSwJff21dCeSJ9HSQamhEhGX7lvHBjg+4\no9cdjOg8Qk/7eBmvSgKFhbBlC0yYYHck5dMjAdWQ5BfmM+/Heew/tZ/nrnmO1iF1OgZU1RGvSgL7\n90N4OERG2h1J+TQJqIbiVPYpnln/DBEBEcwdOldH8Xoxr0oC27ZB7952R1GxRo0gO9vuKJSqWwfS\nDvDUN09xbcdrubXnrQ2u6mZ945K/njFmvjHmuDFmeyVt/mmM2WuM2WqM6VOT7ezdC9261TzOuqZH\nAqq+2/brNv789Z+Z2Hsi4y4cpwmgHnDVX/BtYFhFTxpjRgCdRKQLcB/wek02sncvdPXMqUABTQKq\nfvv6wNe8sOEFHr3yUQbGDLQ7HOUibqkiCozBUWZaRH4wxoQaY1qKyHFnt5GaCnl50LJlbaOtO3p1\nkKqPRIRPf/mUlftX6rX/9ZC7+gRaA0dK3U9yPOZ0Ejh0CNq3t6cwnLP0SEDVN4VFhbz+0+vsSdnD\n3Gvn0ixAa/3UN+5KAuXtuqtVvT8pCVp7+BVomgRUfZJfmM/c7+eSX5jPM0Of0bLO9ZS7kkAi0LbU\n/TbA0fIaVlRKOjHRKhPtyfR0kKov8gvzeea7Z/D38eexgY/RyMerLiSs9zy1lHSFVUSBxcCDwMfG\nmP5AWkX9ARWVkk5Kgssuc0GUdUiPBFR9kF+YzzPrn8G/kT/TL5+uCcADeVwp6aqqiIrIUmPMdcaY\nfcAZrIllqkVPBylV94qkiH/88A98fXw1ATQQbqki6mgzpabrLyiAtDTPHSlcTJOA8nbvbnuXE1kn\neGrQU5oAGgiv+CunpkJYmHXO3ZPpiGHlzVbuX8mmpE3MvWYujRs1tjsc5SZeMdzvxAlo3tzuKKqm\nRwLKW+0/tZ/3tr/HE1c9QUhjnR+1IfGKJJCc7D1JQI8ElLc5k3eGuevncv+l99MmxMMvwVMup0nA\nhfz8ICvL7iiUqp63tr5F76jeDGg3wO5QlA28IgmcPOkdScDfX5OA8i4/H/uZbb9u4+4+1b5gT9UT\nXpEETp2yOoY9XePGcOaM3VEo5Zzcglxe3fwqD/Z9UEcDN2CuKiU93BgTZ4zZY4x5tJzn2xpj1hhj\ntjhKSY+ozvrT0rwjCfj7axJQ3mNR/CI6R3Tm4qiL7Q5F2ajWScAY4wO8glVKuicwzhjTvUyzJ4GP\nReQSYBwwrzrb8JYkoEcCylukZqeyKH4RE/tMtDsUZTNXHAn0BfaKyCERyQc+wiodXVoRUHzdWRhW\nFVGneUsS0CMB5S0+2vUR13S8hqimUXaHomzmiiRQtkx0ouOx0mYD440xR4AlwEPOrrz4kssAL5jC\n1M8P8vOhsNDuSJSqWEpWCusPr+eG7jfYHYryAK4Yg+tMmehxwNsi8qKjgNz7WKeOzlO2imhk5CDC\nwjx7HoFixkBgoHU0EKLjbZSHWhC3gKEdhhLaJNTuUFQNeVoV0USg9FRD5ZWJvhfH9JMistEY08QY\nEykiJ8uurGwV0d27veNUUDFNAsqTnc45zZqDa3h5xMt2h6JqwZVVRF1xOmgz0NkYE2OM8Qduwyod\nXdoh4BoAY0wPoHF5CaA8p09DqBd9YQkK0n4B5blW7F9B/9b9dYYwVaLWSUBECoEpwEpgF/CRiOw2\nxsw2xoxyNJsOTDLGbAU+ACY4u/6MDAgOrm2U7qNJQHmqwqJClu9fzsguI+0ORXkQV5WSXg50K/PY\nzFLLu4EajUnPzISmTWsXnztpElCeavPRzTQLaEaniE52h6I8iMePGNYkoJRrLN27lOu6XGd3GMrD\naBJwsaAgrR+kPE/ymWT2n9rPlW2vtDsU5WE0CbiYHgkoT/TN4W+4vM3l+Pv62x2K8jCaBFxMk4Dy\nROsOrWNQ+0F2h6E8kCYBF9MkoDzNwbSDZOZlckHzC+wORXkgl1wdZIwZDryElVTmi8jcctrcAszE\nqiO0TUTudGbd3pYEgoOty1qV8hTrDq3j6pir8TF1853v99f8nl8Tf62TdbvTAzxgdwhViomJ4eDB\ngy5dZ62TQKkqokOxRgpvNsYsEpG4Um06A48Cl4tIujEm0tn1e1sSCA2F48ftjkKpszYmbuSRyx+p\ns/X/mvgrImUrxai6YOqgfo67qohOAl4VkXQAZ0cLFxVZp1aCglwQpZuEhlqjnJXyBInpieQU5NA5\nvLPdoSgP5a4qol2BbsaY9caY740xw5xZcXa2VaO/kUtOWrlHSAikp9sdhVKWH5J+oF/rfnXyDVLV\nD65IAs5UEW0EdAYGArcD/zbGVFlizdtOBYEeCSjPsjFxI/3a9LM7DOXB3FVFNBHYICJFwEFjTDzQ\nBfip7MpKl5Ju1mwQTZsOckGI7qNJQHmK1OxUkjKSuLD5hXaHolzM00pJl1QRBY5hVREdV6bNQsdj\n7zk6hbsACeWtrHQp6W3bvO9IQE8HKU+xKWkTl0Zfip+vn92hKBfzqFLSzlQRFZEVQIoxZhewGpgu\nIqeqWnd2tnfMKFaaHgkoT7ExaSP9WuupoPbt2xMYGEhISAjR0dHcc889ZGltlxIuuXBYRJaLSDcR\n6SIizzoemykiS0q1+aOI9BSR3iLyqTPr1SSgVM1k52ezO3k3l0RfYncotjPG8NVXX5Gens6WLVvY\nvHkzc+bMOa9dQ73M1aNHDHtjEmja1Cogp/MMKzttP7GdzhGdCfQLtDsUj1C8g4+OjmbEiBHs2LGD\nwYMH8+STTzJgwACCgoI4cOAA6enp3HvvvbRq1Yq2bdsyY8aMktfu37+fQYMGERYWRosWLRg37uxZ\n72nTptGyZUvCwsLo06cPv/zyiy2/Z0149MWX3pgEfHysRJCR4V3TYqr65adjP3Fp9KV2h+Fxjhw5\nwtKlS7nxxhv55ptveP/991m+fDldu3alqKiIm266iVatWpGQkEBmZiajRo2iXbt2TJo0iRkzZjBs\n2DDWrl1LXl4eP/74IwArV65k/fr17Nu3j+DgYOLj4wnzog+/Rx8J5OR4XxIAPSWk7CUibDm6xaOS\ngDGuudXU2LFjiYiIYODAgQwePJg//elPAEycOJHu3bvj4+NDamoqy5cv58UXX6RJkyZERkYydepU\nPvroIwD8/Pw4dOgQSUlJ+Pv7c8UVV5Q8npGRwS+//IKI0K1bN1q2bFnr98xdPDoJeOORAFhHAGlp\ndkehGqrE9ESKpIh2oe2qbuwmIq651dSiRYtITU3lwIEDvPzyyzRu3BiAtm3blrQ5dOgQ+fn5REdH\nExERQXh4OPfffz/JyckAPP/88xQVFdG3b1969erF22+/DcDgwYOZMmUKDz74IFFRUdx///1kZmbW\nPFg38/gk0KSJ3VFUX7NmkJJidxSqofrp2E9cEn2JjhIupaJO39LvUdu2bWnSpAkpKSmkpqZy6tQp\n0tLS2L59OwAtWrTgzTffJCkpiddff50HHniAhATrSvcpU6bw448/smvXLuLj43n++efr/pdyEY9P\nAt54JBAZCSedqo6klOttObaFS1t5zqkgbxEVFUVsbCzTpk0jIyMDESEhIYFvvvkGgM8++4ykpCQA\nwsLC8PHxwdfXlx9//JFNmzZRUFBAQEAATZo0wdfX185fpVpckgSMMcONMXHGmD3GmEcraXeTMabI\nGOPUdWve2iegSUDZJb8wn7iUOC5qcZHdoXiMio6Iynv8vffeIy8vjwsuuICIiAhuvvlmfv3VKpO9\nefNm+vXrR0hICGPHjuWf//wnMTExpKenM2nSJCIiIujQoQORkZFMnz69Tn8nV3JLKWlHu6bAQ8BG\nZ9edlaVJQKnq2JOyhzbBbQjy96LSu3Ws+JRNWWvWrDnvseDgYObNm8e8efPOe27u3LnMnXveVCkM\nGTKEbdu21T5Qm7irlDTAU8BcINfZFevpIKWqZ2fyTnq26Gl3GMqLuKWUtDGmD9BGRJZWZ8V6Okip\n6tl5Yie9WvSyOwzlRVwxWKzSUtLGOvH2IjChitcA51YRTU8fREDAoFoH6G6RkXp1kHK/gqIC9qTs\n0bmEGwBPqyJaVSnpYKAnsNaREKKARcaY0SKypezKSlcRXbBAjwSUcta+1H1ENY2iqb+Xld5V1ebK\nKqJ1XkraMaVki+L7xpivgUdE5OfKVlpYCPn51sxi3iYyEk6csDsK1dDsPLGTC1vo3AGqetxSSrrs\nS6jkdFCx3FwrAXjjeJeoKCsJFBXZHYlqSOJT4ukR2cPuMJSXcUkBORFZDnQr89jMCtoOcWad3npl\nEFjJKyQEkpPBi0qIKC8mIuxJ2cOkSybZHYryMh47YtibkwBAq1ZwtOwkm0rVkZTsFIqkiOaBze0O\nRXkZTQJ1pHVrcIwwV6rO7UnZQ9dmXbVekAutW7funAJz9ZUmgTqiSUC5097UvXSJ6GJ3GB6p9PSS\nrVq14u6773Z6esmGkFQ1CdQRTQLKnYqPBNT5Sk8vuXXrVn7++WeeeeYZu8PyGB6dBLyxjHSxNm3g\nyJGq2ylVW4VFhexL3adHApUoLiXdokULhg0bxtatWwHIy8tj+vTpxMTEEB0dzQMPPEBubvmVbY4d\nO8ZNN91EixYt6NSpEy+//HLJc5s3b+aKK64gPDyc1q1b89BDD1FQUFDyfEXTT1Zn+3XFLVVEjTHT\njDG7jDFbjTGrjDFVnmjz1pIRxTp1ggrqVinlUkkZSYQ1CSO4cbDdoXi8xMREli1bRpcuVsL8f//v\n/7Fv3z62b9/Ovn37SEpK4i9/+ct5rxMRrr/+ei6++GKOHTvG6tWr+cc//sGqVasA8PX15aWXXiI1\nNZUNGzawZs2akiJ0paefTEtL4+OPP6ZZs2bV2n5dclcV0S3ApSKSY4y5H3gea1BZhbz9SKBzZ9i3\nz+4oVEPgDaeCzGzXnFuXmTWbXmzs2LEAZGZmMnToUGbNmgXAv//9b3bs2EFoaCgAjz32GHfccQdP\nP/30Oa/ftGkTJ0+e5IknngCsfobf/e53fPTRR1x77bVccsnZ6vjt2rXj97//PevWrePhhx8+Z/rJ\nvn370q3b2avpnd1+XXLFOIGSKqIAxpjiKqIlSUBE1pVqvxG4o6qV1oc+gdRUOHMGgrSqr6pDe1L3\nePypoJruvF1l0aJFDB48mG+++YY77riDkydPkpubS1ZWFpdeenYCnqKionJnITt8+DBJSUlEREQA\n1pFBUVERAwcOBGDv3r088sgj/Pjjj2RnZ1NQUFCy3tLTTx45coTf/va3vPDCC2RnZzu9/brkliqi\nZdwLLKtqpd6eBHx8oGNH2L/f7khUfbc3Za/HHwnYrXjHOnDgQCZMmMD06dOJjIwkMDCQXbt2kZqa\nSmpqKmlpaZw+ffq817dt25aOHTuWtDt16hSnT5/myy+/BGDy5Mn06NGD/fv3k5aWxtNPP33Ozry8\n6Sers/265IokUGkV0XMaGnMncCnW6aBKeXufAECXLhAfb3cUqj7LLcglMT2RjuEd7Q7Fa0ydOpVV\nq1axfft2Jk2axNSpU0smk09KSmLlypXnvaZv376EhITw3HPPkZOTQ2FhIbt27eLHH38EICMjg5CQ\nEAIDA4mLi+O1114reW1F008aY5zefl1yRRKoqoooAMaYa4DHgesdk8+U68MPZ/Hhh7PYvXsWyclr\nXRCefS66CLx4wiHlBRLSEmgb0hZ/X3+7Q/FYZa/1j4yM5K677mLOnDnMnTuXzp07079/f8LCwoiN\njWXPnj3nrcPHx4cvv/ySrVu30qFDB1q0aMGkSZNIT08H4IUXXuCDDz4gJCSE++67j9tuO9vlWdn0\nk85uv6y1a9cya9asklttmNqefzLG+ALxWB3Dx4BNwDgR2V2qzcXAp8AwEanwBIkxRhYvtuKZMweu\nvRb69atVeG6VmAiTJ5+9v2ABzJ8PS5bYF5PyHq9tfo02IW2q9ZpF8Ys4mnGUyb+ZXHXjOjK6+2i3\nn8duqIwx5b7Xjsdr1PvuriqizwFBwKfGmJ+NMQurWq+3Xx0EcPHF8HOlBbOVqp29KXvpGqH9Aarm\n3FJFVESure46s7MhMNAFwdkoJsYqiZ2YaA0eU8rV9qTs4Zaet9gdhvJiOmK4DhkDgwbB11/bHYmq\nj07nnCY9L73ap5CUKs1jk0BOjvcnAYAhQ2DNGrujUPVR8fgAH+OxH2PlBTz2v8fbxwkUGz4cli6F\nUmVElHIJbxgprDyfRyYBkfoxTgCsAWPt28Pq1XZHouqb+JPxdGvWreqGSlXCJR3DrpaXB40aga+v\n3ZG4xsSJ8NprMGyY3ZGo+qJIitib6hkjhaPaRDWIuvueICYmxuXr9MgkUB86hUubMAFmz4YtW6BU\nnSmlauxoxlGC/IMIaxJmdyi8+b837Q6h1hLTE5l8mX1jLezkrlLS/saYj4wxe40xG4wx7cpbTzFv\nTQJ79qwt9/HAQJg7F+65x7pk1FOtXbvW7hBqxdvj3/NT1SNFi+1K3kWPyB51GE317fhhh90h1Fh1\n3vv6ptZJoFQp6WFAT2CcMaZ7mWb3Aqki0gV4CWvwWIWysryzP6CiJABw113QowfceCNkZrovpurw\n9p2ot8dfnR3R1l+30qdlnzqMpvp2bNIk4I1ccSRQUkraUROouJR0aWOAdx3Ln2GVmKjQ6dMQZv9R\nrksZA++9B1FR0KsXvP46OGpGKVUthUWFbD++nT5RnpUElHdyRZ9AeaWk+1bURkQKjTFpxpgIEUkt\nu7I5q//OyRQwvWDhcRdE50YH8jfw9w1/r7TNBfdC40Ew71uY+jE0DYZmERASAv7+0Lgx+PlZSQMD\nPsZaLu53Mz7ll211hfhvN7Dlmcrj92TeHv+PvyQz5z/fVtku0yQRYDry7ceXuSEq58VtDWfh295Z\nzfTAjpb83Xv/dWrFFQXkbgJiReT3jvt3ApeJyB9KtdnpaHPUcX+fo82pMuvSKlRKKVUDNS0g54oj\nAWdKSR8B2gJHHVVHQ8omAKj5L6GUUqpmXNEnsBnobIyJMcb4Y80dvLhMmy+BCY7lmwEtpKCUUh6g\n1kcCjnP8xaWkfYD5xaWkgc0isgSYD/zHGLMXSKGKSeaVUkq5R637BJRSSnkvW2oHuXpwmbs5Ef80\nY8wuY8xWY8wqY0xbO+KsSFXxl2p3kzGmyBjjUeOcnYnfGHOL42+wwxjzvrtjrIwT/z9tjTFrjDFb\nHP9DI+yIszzGmPnGmOPGmO2VtPmn47O71RjjUdexVhW/MeZ2Y8w2R+zrjTG93B1jRZx57x3tLjPG\nFBhjbnBqxSLi1htW4tkHxAB+wFage5k2k4F5juVbsWYrc3ustYj/aqCJY/l+b4vf0a4psA74HrjE\n7rir+f53Bn7CugABINLuuKsZ/xvAfY7lHsABu+MuFdsAoA+wvYLnRwBfOZb7ARvtjrma8fcHQh3L\nwz0p/qpiL/X/tRpYAtzgzHrtOBJw+eAyN6syfhFZJyI5jrsbscZJeApn3n+Ap4C5gKcVunAm/knA\nqyKSDiAiJ90cY2Wcib8ICHEshwFJboyvUiKyHjjvyr5SxgDvOdr+AIQaY1q6IzZnVBW/iGwUkdOO\nux712XXivQd4CGufecLZ9dqRBMobXFb2jT5ncBmQZoyJcE94VXIm/tLuBZbVaUTVU2X8jkP4NiKy\n1J2BOcmZ978r0M1xOP+9McaT6rc6E/9sYLwx5gjWN7qH3BSbK5T9/ZLwoB1pNf0Oz/rsVsoY0woY\nC7xONcaU2lFFtLzgyvZOl21jymljF2fitxpaA+cuxTo95Ckqjd9YNYFf5OwlvRW9xi7OvP+NsE4J\nDcQaw/KtMaZn8ZGBzZyJfxzwtoi8aIzpD7yPVZfLGzj9+fBkxpjBwN1Yp2C8xUvAoyIijtLeTn1u\n7UgCLhtcZhNn4scYcw3wODDQcdjvKaqKPxhrh7PWkRCigEXGmNEissV9YVbImfc/EdggIkXAQWNM\nPNAFq5/Abs7Efy9WQUZEZKMxpokxJtLDTmtVJBHrs1us3M+HJzPGXAS8CQz3oP2OM34DfOT43EYC\nI4wx+SJSdtzWuWzo3PDlbMeYP1bHWI8ybR7gbMfwbXhWx6oz8V/saNPJ7nhrEn+Z9l8DF9sddzXf\n/2HAO47lSOAQEG537NWI/ytggmO5B5Bod9xl4msP7Kjgues42zHcHw/qWHUy/nbAXqC/3XFWN/Yy\n7d7GyY5htx8JiJcPLnMy/ueAIOBTR1Y+JCJj7Yv6LCfjP+cleNDpIGfiF5EVxphYY8wuoACYLh7y\njc7J93868C9jzDSsTuIJFa/RvYwxHwKDgGbGmMPATKxkJiLypogsNcZc56gPdgbrlIrHqCp+YAYQ\nAcxzfHbzRaRsQUxbOBF7aU6fgtPBYkop1YB55ETzSiml3EOTgFJKNWCummPYa4diK6VUQ+aqI4G3\ncVzSVoEErEsl+wBzgH+5aLtKKaVqwSVXB4nIemNMTCXPbyx116OGYiulVENmR5+AVw3FVkqp+syt\n4wSqGoptdI5hpZSqEanh9LxuOxIoNRR7dGUDd+wekVeb28yZM22PQeO3Pw6N3/tu3hy7SO2+O7sy\nCRgqGFnqmBTmc2C8iOx34TaVUkrVgktOB3nzUGyllGrIXHV10O1VPD8Ja6KPem3QoEF2h1ArGr+9\nNH77eHPsteVRtYOMMeJJ8SillDcwxiCe3jGslFLK82gSUEqpBsyOmcWUUko5iAj5RfnkFOSQV5hH\nfmG+9bMo3+nl2tAkoJRS5SiSIs7knSEzL7PCW0ZeRslyVn4WOQU5591yC3PPf6zg3Md8fXxp7NuY\nxo0a4+/rj5+PH36+fk4t+/n41er3dEnHsDFmPjAKOC4iF1XQ5p/ACKzZhiaKyNZy2mjHsFLKJbLz\ns0nJTiGM77ShAAAgAElEQVQtJ61at9I79UC/QJr6Nz3vFtw42Fr2O/tYoF8gAX4BNGnUhMa+jWnS\nqMl5t8aNzn+8sW9jfH18a/W71qZj2FVJYACQCbxXXhIwxowApojISGNMP+AfItK/nHaaBJRS5cot\nyOXXzF85mnGUE2dOkJyVTPKZZE5mnbSWsxzLZ6zlwqJCmgU2I7xJOGFNwghtEkpYkzDCGodZP8u5\nhTYJJdjf2sEH+QfhY7yj27Q2ScAtVUSBMcB7jrY/GGNCjTEtReS4K7avlPJuZ/LOcCDtAAfTDpKU\nnsTRjKMkZVg/i5dP55wmqmkU0cHRtAxqSWRgJM0DmxMdHE2vlr1oHtic5kHNaR7YnMjASJr6N8Ua\nm6oq464+gdbAkVL3kxyPaRJQqgEQEY5mHCXuZBz7UvdxIO1AyU7/wKkDZORl0D6sPe3D2tMmuA2t\nQ1rTt3VfWgW3onVwa1oFt6J5UHOv+WbuTdyVBMpLx3reR6l66FT2KTYkbmD78e3sPrmb3cm7iTsZ\nR4BfAN0ju9M5vDMdwjswuutoOoR3oENYB6KaRum3dpu4KwkkAm1L3W8DHC2v4axZs0qWBw0a1KCH\ncyvl6USEhFMJfHfkO747/B3fHfmOQ6cP0bd1Xy6JuoSB7QZy36X30T2yOxEBEXaHW2+sXbuWtWvX\numRdLisbYYxpD3wpIufNH2yMuQ540NEx3B94qT52DGdmQlAQ6BcaVV/lF+bz868/l+zwvzvyHT7G\nhyvbXsmAdgO4su2V9I7qTSMfvfrcnTzh6qCSKqJY5/nLVhHFGPMKMBzrEtG7RWRLOevx2iTwyy/Q\nsyc89RQ8+aTd0SjlGmk5aWw4soH1h9fz3ZHv+OnYT3QM78iVba+0bu2uJCY0Rk/l2Mz2JOAq3poE\n4uJg6FC44w745BM4cECPBpR3OnL6CN8c+oZvD3/Ld0e+42DaQS5rdVnJDv/yNpcT2iTU7jBVGZoE\nbBQfD0OGwF//ChMmQLt28L//QdeudkemVOVEhH2p+1h3aF3Jjv9M3hkGxgxkQLsBDGg3gN4te+Pn\nW7sRqaru2T5OoKHatw+uucY6BTRhgvXYgAGwfr0mAeWZCooKWH94PV/Gf8niPYvJzs9mUPtBDIwZ\nyJ+u+hPdmnXTUzsNjCaBGtq/3zoC+POf4Z57zj5+1VXw7bfnPqaUndJz01m+bzmL4xezbN8yOoR1\nYHS30Xx686f0btlbd/oNnJ4OqoEDB2DQIHj8cbj//nOf274dbroJ9uyxJTSlADiUdogv93zJ4vjF\nbEzcyIB2AxjdbTSjuo6iTUgbu8NTLqZ9Am506JCVAKZPhwcfPP/5wkJo1sxKAi1auD081UAVSRFb\njm1hcfxiFscvJikjiZFdRjK622iu7XgtwY2D7Q5R1SHtE3CTI0esU0DTppWfAAB8faF/f/j+exg7\n1r3xqYZFRPgh6Qc+3vkxn/7yKU39mzK622heue4VLm9zea0rU6qGwSVJwBgzHHgJa6ay+SIyt8zz\nbYF3gTBHm8dFZJkrtu0uiYkweDBMmQIPP1x52yuvhO++0ySgXE9E+PHoj3yy6xM++eUTAv0CubXn\nrawcv5ILml9gd3jKC9U6CRhjfIBXgKFYpSA2G2MWiUhcqWZPAh+LyBvGmB7AUqBDbbftLkePWkcA\n991nHQVU5cordcCYch0RYeuvW/l418d8susTfH18ubXnrSwZt4QLW1yoHbuqVlxxJNAX2CsihwCM\nMR9hlY4unQSKgBDHchhWFVGvcOyYlQDuuQf+7/+ce02/frBtG+TkQJMmdRufqp9EhB0ndvDJrk/4\neNfHFBYVcmvPW/n8ls/pE9VHd/zKZVyRBMqWiU7ESgylzQZWGmMeBgKBa1yw3Tp3/Lg1EvjOO+Gx\nx5x/XVAQ9OgBP/1kHRUo5axfkn/h450f88kvn5CVn8UtF9zCf2/8L5dGX6o7flUnXJEEnCkTPQ54\nW0RedBSQex/oWd7KPKWKaFoaxMbCzTfX7NTOoEGwapUmAVW1+JPxJd/403LSuKXnLbw95m36te6n\nO35VLo+qIurYqc8SkeGO+49hFY6bW6rNTmCYiCQ57u8H+onIyTLr8ohLRM+csRLAZZfBiy/WrA7Q\nunXwyCPW0YBSpRVJET8d/cm6nHPPYpLPJHPTBTdxa89bubzt5Tpxiqo2W8cJGGN8gXisjuFjwCZg\nnIjsLtXmK+ATEXnX0TG8SkTOG7HiCUkgLw/GjLGu8X/7bfCp4eexoABatrT6Btro2JwG71jGMVYl\nrGLF/hWs2r+KZoHNuL7r9Vzf9XquaHuFXs6pasX2wWKOS0T/wdlLRJ81xswGNovIEseO/19AU6xO\n4v8TkdXlrMfWJFBYaFUCzc6Gzz+HRrU8WTZxIvTqBX/8o0vCU14kvzCfbw9/y/J9y1mxfwWHTx9m\naIehDOs0jNhOscSEVTYlt1LVY3sScBU7k4AITJ5sjfRdutQ1V/V8/72VCOLjtbR0Q3Am7wzL9y1n\nYfxCvtrzFV2adWFE5xEM6zSMy1pfphOtqDqjI4Zd4IknrPP3a9a47rLOyy+31rV8OYwY4Zp1Ks9y\nMuskX8Z/ycL4hXx94Gv6t+nP2O5jeXbos7QOaW13eEpVSY8EgBdegPnzreqfkZGuXfeCBVal0Z9/\nrv3pJeUZDqYdZFHcIhbELeDnX3/mmo7X8Nvuv2Vkl5GEB4TbHZ5qgPR0UC3Mn2/NB/Dtt9C2revX\nL2JdaXT55fCXv7h+/aruiQhbjm1hUfwiFsUv4mjGUUZ1HcVvu/+WazteS4BfgN0hqgZOk0ANff45\nPPQQrF1bt5PAnDgBfftaNYemTdP+AW+QV5jH2oNrWRS3iMV7FhPQKIAx3cYwpvsYLc6mPI4mgRpY\ntcq6EmjFCrj44rrf3pEjVkG5pk3h0UetGcn8/et+u8p5aTlpLN27lEXxi1ixbwU9mvewdvzdxtA9\nsrsO3FIey/YkUFUVUUebW4CZWJeIbhORO8tp45YksHEjXH89fPGFNROYuxQUwHvvWaegtm+Hiy6C\nzp0hKsoal9C0KQQEQGCg9TMgAPz8zr01alT+cun7vr56tOEMEWH78e2s2L+CFftXsDlpM1e3v5rR\nXUdzfbfriWoaZXeISjnF7sFiPsAeSlURBW4rXUXUGNMZ+BgYLCLpxpjIsqOFHe3qPAns3GnVA3rr\nLRg5sk43Vam0NNi61Zql7Phx63bmjDVGITsbsrKsn/n5Z28FBRXfL71cVFR5kmjUyEoUvr7WYDgf\nn7PLNf3pLes4XXCCLWmr2JS6gk0pKwlqFEz/FrFc2XIYl0cNpal/UK237+OjSVi5l91JoD8wU0RG\nOO6XVzZiLhAvIm9Vsa46TQIJCTBwIDz/PIwbV2ebsV1RUdUJo7DQaldUdHa5pj89eR0FhYWcCvqB\nE+FLSA1fTnaTBEJTBxOSPIzgE7H4ZXZ0eRwiVhLw5GRYV+uoTzdvSuR2jxNwpopoVwBjzHqsU0az\nRWSFC7bttEOHrPPwf/pT/U4AYP0D+/s33D6H0zmnWbF/BUv2LGHZvmW0Cm7FHV1Gcl2Xf9KvdT/8\nfP3qdPsitU8onpZY8/Kce03p393bb2B/InL2VhvuqiLaCOgMDATaAd8aY3qKSLoLtl+lQ4esWcH+\n8Ad44AF3bFG5296UvXy550uW7FnCj0d/5KqYqxjVZRRzhsyhXWg7t8ZSfBTg62udflPeyVsSWmEh\nfPZZzX9PVySBRKwde7E2WH0DZdtsEJEi4KAxJh7oApxXY9PVpaQPHz6bAP7wh1qtSnmQ/MJ81h9e\nz5I9S1iydwkZuRmM6jqKaf2nMaTDEIL8g+wOUXm50snc03haKWlnqogOczw20RgTibXz7yMip8qs\ny6V9AkeOWHX9H3oIpk512WqVTU5mnWTZ3mUs2buElftX0iWiC6O6jmJU11FcHHWxXsKpGixb+wRE\npNAYMwVYCSWXiO4uXUVURFYYY2KNMbuAAmB62QTgasUTwz/4oCYAbyUi7ErexZfxX7Jk7xJ2ntjJ\n0A5DGdV1FP8Y/g+9hFMpF6iXg8WOHrWOACZNcn5eYOUZCosK2ZC4gQW7F7AwfiGFRYVc3/V6RnUd\nxdXtr6ZJI520WamybB8s5iquSALJydYAsIkTqzcvsLJPTkEOqxNWszBuIYv3LCaqaRS/7f5bxnYf\nS++WvfU0j1JV0CTgkJFhnQIaPhzmzHFhYMrljmceZ+nepSzZu4TVCau5qOVFjO0+lrHdx9IxvKPd\n4SnlVTQJALm5cN110KULvPaadw30aAhEhG3Ht1lX8+xZQtzJOGI7xTKq6yhGdB5B86DmdoeolNdq\n8ElABCZMsMoufPKJZ17S1RBl52ez5sCakss4G/s2Ljm/f1XMVfj7NtDRbEq5mN0jhm333HOwa5c1\nJ4AmAPuICPtP7Wfl/pUs37ectQfXckn0JYzqOopV41fRrVk3Pb+vlIfx+iOBVausTuAffoA2beom\nLlWxU9mnWHNgDSv3r2RVwipyC3O5tuO1DOs0jGGdhxEREGF3iErVe7afDnKmlLSj3U3AJ8BvRGRL\nOc9XKwmcPAl9+sA771h1gVTdyy/M54ekH0p2+rtO7GJAuwFc2/FaYjvFckHzC/Tbvou0b9+eQ4cO\n2R2G8iAxMTEcPHjwvMftriLqQxWlpB3tmgJfAX7AFFckgdtvh+ho+NvfavELqColnEpgxb4VrExY\nydcHvqZjeEdiO8US2ymWK9teSeNGje0OsV5yfLDtDkN5kIr+J+zuE+gL7BWRQ45gPgLGAHFl2j0F\nzAVcMnzr229h/XqIK7sVVWtn8s7wv4T/sXL/SlbsX8GZ/DPEdorlph438caoN2gR1MLuEJVSLuKW\nUtLGmD5AGxFZaoypdRIoKrKKwT33nDULl6q9U9mnWLJnCV/EfcGaA2u4rNVlDO88nC9u/YJeLXrp\nKR6l6qk6LyVtrL3Hi8CEKl4DOFdFdNEi6yqgW2+tfrDqrOOZx1kUv4gvdn/BhsQNDG4/mBt63MBb\no98iPCDc7vCUUhXwtCqi/YFZIjLccf+cmcWMMSHAPiATa+cfBaQAo8v2CzjTJyACl19u1QS68cZa\nhd4gHT59mAW7F/BF3Bds+3UbI7qM4IbuNzCiywia+je1OzxVivYJqLLqok/ALaWky7T/GnhERH4u\n57kqk8D331sDw+LidEyAs/am7OXz3Z/zxe4vSDiVwOhuo7mhxw1c0/EaLcjmwTQJqLLqIgnUcmIy\nq5Q0UFxKehfwUXEpaWPMqPJeQiWng6ryzjtw772aACojImw/vp2ZX8+k12u9uPqdqzly+gjPDH2G\nY388xltj3mJU11GaAFSttG/fnsDAQEJCQoiOjuaee+4hKyvLJeuePXs248ePd6rtu+++y1VXXeWS\n7dbEoUOH8PHxoah4Tkov45IRwyKyHOhW5rGZFbQdUtPt5OTA55/D1q01XUP9VVBUwPrD61kUt4hF\n8YsQhBt73Mgbo96gf5v++Jha53ulzmGM4auvvmLw4MEcO3aM2NhY5syZw1//+tfz2opItS8ucLZ9\nTdZdHUVFRfhUMpFv8fZretRWWFiIr43far1qz/DVV9C7N7Rta3ckniEzL5PPf/mcuxbcRdQLUUxf\nOZ3wgHAW3LqAhIcTeCH2Ba5oe4UmAFVnind80dHRjBgxgp07dwIwePBgnnzySQYMGEBQUBAHDhwg\nPT2de++9l1atWtG2bVtmzJjh9I7Tx8eHN954g65du9KsWTOmTJkCQFxcHJMnT2bDhg0EBwcTEWGN\nUM/Ly2P69OnExMQQHR3NAw88QG5ubsn6nnvuOVq1akWbNm2YP38+Pj4+JCQkAHD33XfzwAMPMHLk\nSIKDg1m7di1Lly7lkksuITQ0lJiYGGbPnl2yrquvvhqAsLAwQkJC+OGHHxAR5syZQ/v27YmKimLi\nxImkp1tTqhcfObz11lvExMQwdOjQ2vwJak9EPOZmhVOxu+4SefXVSpvUe8cyjskbP74h131wnQT/\nNVhi/xMrr256VY6cPmJ3aMrFqvo82K19+/ayevVqERE5fPiw9OzZU2bOnCkiIoMGDZKYmBjZvXu3\nFBYWSn5+vowZM0YmT54s2dnZkpycLP369ZM333yz3HXPmjVLxo8fX3LfGCPXX3+9pKeny+HDh6V5\n8+ayYsUKERF555135Kqrrjrn9X/4wx9kzJgxkpaWJpmZmTJ69Gj505/+JCIiy5Ytk+joaNm9e7dk\nZ2fL+PHjxcfHR/bv3y8iIhMnTpSwsDDZsGGDiIjk5ubKunXrZOfOnSIismPHDomKipJFixaJiMjB\ngwfFx8dHioqKSrY/f/586dKlixw8eFDOnDkjN9xwQ8nvc/DgQTHGyIQJEyQrK0tycnKcfs8r+p9w\nPF6z/W5NX1gXt8r+6QsLRVq2FHH8nRqUfSn75Pnvnpcr5l8hYc+GyW2f3SYf7fhI0rLT7A5N1SFn\nkoB1vVztbzXRvn17CQ4OlvDwcGnfvr1MmTKlZIc2aNCgkoQgInL8+HFp3LjxOTu8//73vzJ48OBy\n111eEvj+++9L7t9yyy0yd+5cESk/CQQFBUlCQkLJ/e+//146dOggIiL33HNPSUIQEdm3b995SWDC\nhAmV/u5Tp06VRx55RETOJoHCwsKS54cOHSqvvfZayf34+Hjx8/OTwsLCkvYHDx6sdBvlqYsk4DVV\nRLdvh9BQ6NgA5hsREbb+upUFcQtYELeA5DPJjOk2hhkDZzC4/WAt06BK1PA0tMssWrSIwYMHl/tc\n21LnbQ8dOkR+fj7R0dHA2S+f7dq1c3pbLVu2LFkODAwkMzOz3HbJyclkZWVx6aWXljxWVFRU/EWT\no0ePctlll50Tp5R5I9uWOee8adMmHnvsMXbu3EleXh55eXncfPPNFcZ69OhRYmJiSu7HxMRQUFDA\n8ePHSx5r4yEVL70mCSxfbs0YVl+JCJuPbuazXz7js18+w8f48Nvuv9WOXeXRyu48SyvdWdu2bVua\nNGlCSkqKyztxy64vMjKSwMBAdu3aVZJ0SouOjiYxMbHk/uHDh89bR9n7t99+Ow8//DArVqzAz8+P\nadOmkZKSUm5bgFatWp1T/O/QoUP4+fnRsmVLjhw5UuHr7OCSPYsxZrgxJs4Ys8cY82g5z08zxuwy\nxmw1xqwyxlS7a3ftWhhS4+uKPFORFLHhyAb+uOKPtP9He8YvGI+/rz8Lbl3A3of28nzs89qxq+qF\nqKgoYmNjmTZtGhkZGYgICQkJfPPNN7Ved8uWLUlMTCQ/Px+wdq6TJk1i6tSpJCcnA5CUlMTKlSsB\nuOWWW3j77beJi4sjKyuLp556qsptZGZmEh4ejp+fH5s2beLDDz8sea558+b4+Piwf//+ksfGjRvH\niy++yMGDB8nMzOSJJ57gtttuK7nKqLLk6W613rs4qoi+AgwDegLjjDHdyzTbAlwqIn2Az4Hnq7MN\nEdi8Gfr2rbqtpxMRNidtZuryqcS8FMPvvvwdTf2b8tXtXxH3YBxzhsyhd5ROrq48X2X/o+U99957\n75GXl8cFF1xAREQEN998M7/++muNtlX6/pAhQ+jZsydRUVG0aGEVN3z22Wfp3Lkz/fv3JywsjNjY\nWPbs2QPA8OHDefjhhxk8eDBdu3bliiuuAKBx44pPs86bN48ZM2YQGhrKnDlzuLVUzZqAgACeeOIJ\nrrzySiIiIti0aRP33HMP48ePZ+DAgXTq1InAwED++c9/Vvr+2MVVZSNmisgIx/1zykaU074P8LKI\nnDe6o6IRwwkJMHAglDqC8zr5hfm8u+1dXt70Mhm5GUzoPYGbe97MBc0vsDs05aF0xLB7xMXF0atX\nL3JzcysdD+AJPLWUdJVVRMu4F1hWnQ1s3gyl+nG8zuakzYxfMJ5Wwa34W+zfGNJhiJ7iUcpGCxcu\nZOTIkWRmZvLoo48yevRoj08AdcUVv3WlVUTPaWjMncClVPN0kDcngYVxCxn54UjmDJnD6rtWc03H\nazQBKGWzN954g+bNm9OlSxf8/PyYN2+e3SHZxhVHAolA6eu82mDNMHYOY8w1wOPAQBHJr2hl5ZWS\n3rwZnnzSBZG62eakzfz+y9+z/M7lXBJ9id3hKKUcli2r1skIj+NppaSrrCJqjLkY+BQYJiL7y10R\n5fcJFBZCeDgcOmT99BY5BTlc/MbFzLp6FrdeqBMfqOrTPgFVljdXEX0OCAI+Ncb8bIxZ6Oz64+Kg\nZUvvSgAA//rpX3QK76QJQCnl0dxSRVRErq3pur2xP0BE+NuGv/HJzZ/YHYpSSlXK43sovTEJ/HTs\nJxo3asxlrbwscKVUg6NJoA4sjFvI2G5jPWpAiFJKlcejk0BuLuzcCRdfbHck1bM4fjFjuo+xOwyl\nlKqSRyeB7duhc2cICrI7EucdSjvEscxj9Gvdz+5QlKpTrp5e0plpGnXaSdfz6CTgjaeC5v88nxt7\n3Iivj06CrOq34ukl09PT2bJlC5s3b2bOnDk1Xp+Ic9M0etK0k85sv6aX+RYWFtboddXl0Ulg40bo\n39/uKJyXkpXCvM3zmH7FdLtDUcotindwZaeXPHbsGGPGjKFZs2Z07dqVf//73yWv2bx5M5dddhmh\noaFER0czfbr1eSlvmsaq6LSTLlDT2WhK34DhQBywB3i0nOf9gY+AvcAGoF0F6zlntpz27UV27y53\nIh3bpOeky+7k3bJq/yp55+d35OlvnpbJSybL6P+Olg4vdZCpy6baHaKqJ8p+HjxNZdNLDhw4UKZM\nmSJ5eXmydetWad68uaxZs0ZERC6//HJ5//33RUTkzJkz8sMPP4hI+dM0ltXQp52s6H8CO2cWK1VK\neihWuYjNxphFIhJXqtm9QKqIdDHG3Io1eOy2ytablAQZGdCtW2WtXKdIikg+k0xSRhKJ6YkkpSed\nXc5IIindWi6UQtqEtKF1cGtah7SmTXAbLmh+Add2vJa2oW25OMrLerGVVzOzXXO6Q2bW7JTF2LFj\nadSoEaGhoYwaNYrHH3+cxMREvv/+e5YtW4afnx+9e/fmd7/7Hf/5z38YPHgwfn5+7Nu3j5SUFJo1\na0bfMjXipZqncR5//HGCg4MJDg5m8ODBbN26ldjY2HLb/vvf/2bHjh2EhoYC8Nhjj3HHHXfw9NNP\n8+mnn3L33XfTvbtVCX/mzJl88MEH57x+zJgx9HecnvD392fgwIElz1144YXcdtttrFu3jtGjR5f7\n+3z44Yc88sgjJbOOPfPMM1x44YW88847gHWqa/bs2QQEBDj9+9eWKwaL9QX2isghAGPMR8AYrCOD\nYmOA4sFjn2EljUotXgzXXguuOKWXW5DL0Yyj5+zQy+7gj2UeI6RxyNkdfHBr2oS0YWDMwJLl1iGt\nCW0cqpd+Ko9R0523q5Q3veTRo0eJiIggMDCw5LGYmBh++uknAN566y1mzJhB9+7d6dixI3/+858Z\nOXJkjWPQaSdrx12lpEvaiEihMSbNGBMhIqllV/bov5az/cBRvt+Uy7w/jHa8tHwiwunc0yXf0kt/\nY0/KOLujP51zmujg6LM7c8fPvq37liy3Cm6lc/cqVU1ld5JgTa2YmprKmTNnCHJc2nf48GFat7Y+\ny506dSqZmevzzz/npptuIjU1VaedtGnaSVckAWdKSZdtY8ppA8Arbz9IsH8wzYKK+OOK2eS0fpqT\nWSc5ceYEyVnJnDhz4pzlxr6NaR3S+pwdfO+o3ozsOrLklE2LoBZavlkpN2nTpg1XXHEFjz/+OM8/\n/zzx8fHMnz+/ZMf/wQcfMGzYMCIjIwkNtY6sfX19z5mmsUuXLrWOo/S0k35+fudMO/nKK6/QvHlz\nkpKS2LVrF7Gxsdxyyy3ce++93HnnnbRr167G004OGzYMoNzfZ9y4cTz33HMMHz6cyMjIGk876coq\nou4qJX0EaAscdVQdDRGRU+Wt7Mz3Z4uMvrP1HVYfWE3LoJZENY3iopYX0SKoBc2Dmls/A5sT4Oe+\nc2dKqbMq+8b63//+l/vuu49WrVoRERHBU089xRDHJOHLly/nkUceITs7m5iYGD7++GP8/f0BSqZp\nLCgoYPny5ef1F1QVQ0XTTvr6+nLixAmeffZZ/vKXv9C/f39SUlJo3bo1kydPJjY29pxpJ319fZkx\nYwbvv/9+ldNOPvLII0yZMoWrr76aW2+9lbS0NODcaSeLf5977rmHY8eOMXDgQHJzcxk+fHiNpp0s\nLrNfrPRVSdXlrlLSDwAXisgDxpjbgLEicl7HcEXTSyrVEGkpaXt54rST3lxKej4QaYzZC0wFHqvt\ndpVSytUWLlxIfn4+p06dajDTTtb6SMCV9EhAqbP0SMD9RowYwYYNG2jUqBGDBg3i1VdfPefqI7vV\nxZGAJgGlPJQmAVWWR54OUkop5b00CSilVAOmSUAppRowl8wxrJRyvZiYGC1Ros5RuuSEq9SqY9gY\nEw58DMQAB4FbROR0mTa9gdeAYKAQ+KuIlDsDu3YMK6VU9dnZMfwY8D8R6QasAR4vp80ZYLyI9AJG\nAC8ZY0JquV2P5Kph3HbR+O2l8dvHm2OvrdomgTHAu47ld4GxZRuIyD4R2e9YPgacAJrXcrseydv/\nkTR+e2n89vHm2GurtkmghYgcBxCRX6li526M6Qv4FScFpZRS9qqyY9gYswooPWSuuALok9XZkDEm\nGngPcG6WaKWUUnWuth3Du4FBInLcGBMFfC0iPcppFwysBZ4WkS8qWZ/2CiulVA3UtGO4tpeILgYm\nAnOBCcCisg2MMX7AQuDdyhIA1PyXUEopVTO1PRKIAD7BmivgMHCziKQZYy4F7hOR3xtj7gDewqow\nWnwqaaKIbK919EoppWrFowrIKaWUci9bykYYY4YbY+KMMXuMMY+W87y/MeYjY8xeY8wGY0y78tZj\nFyfin2aM2WWM2WqMWWWMaVveeuxSVfyl2t1kjCkyxlzizviq4kz8xphbHH+DHcaY990dY2Wc+P9p\na3G0C5YAAAQESURBVIxZY4zZ4vgfGmFHnOUxxsw3xhw3xlR4JG+M+afjs7vVGNPHnfFVpar4jTG3\nG2O2OWJfb4zp5e4YK+LMe+9od5kxpsAYc4NTKxYRt96wEs8+rFHGfsBWoHuZNpOBeY7lW7EmqnF7\nrLWI/2qgiWP5fm+L39GuKbAO+B64xO64q/n+dwZ+wprGFCDS7rirGf8bWKdTAXoAB+yOu1RsA4A+\nwPYKnh8BfOVY7gdstDvmasbfHwh1LA/3pPirir3U/9dqYAlwgzPrteNIoC+wV0QOiUg+8BHWoLPS\nSg9C+wxr6kpPUWX8IrJORHIcdzcCrd0cY2Wcef8BnsLq8M91Z3BOcCb+ScCrIpIOICIn3RxjZZyJ\nvwgoHlUfBiS5Mb5Kich6oNz5wR3GYF0Kjoj8AIQaYzxmVpaq4heRjXK29I1HfXadeO8BHsLaZ55w\ndr12JIHWWBPPF0vk/De6pI1Y01emOTqhPYEz8Zd2L7CsTiOqnirjdxzCtxGRpe4MzEnOvP9dgW6O\nw/nvjTHD3BZd1ZyJfzYw3hhzBOsb3UNuis0Vyv5+SXjQjrSafodnfXYrZYxphVW14XWsi3CcYkcV\n0fKCK9s7XbaNKaeNXZyJ32pozJ3ApVinhzxFpfEbq2zli1iX/Fb2Grs48/43wjolNBBoB3xrjOlZ\nfGRgM2fiHwe8LSIvGmP6A+8DPes8Mtdw+vPhyYwxg4G7sU7BeIuXgEdFRBzVZ5363NqRBBKxPpjF\n2gBHy7Q5gnXZ6VFjjC/Wud2qDoPcxZn4McZcg1VQb6DjsN9TVBV/MNYOZ60jIUQBi4wxo0Vki/vC\nrJAz738isEFEioCDxph4oAtWP4HdnIn/XmAYWKcnjDFNjDGRHnZaqyKJWJ/dYuV+PjyZMeYi4E1g\nuAftd5zxG+Ajx+c2EhhhjMkXkcWVvsqGzg1fznaM+WN1jPUo0+YBznYM34Zndaw6E//Fjjad7I63\nJvGXaf81cLHdcVfz/R8GvONYjgQOAeF2x16N+L8CJjiWewCJdsddJr72wI4KnruOsx3D/fGgjlUn\n428H7AX62x1ndWMv0+5tnOwYdvuRgIgUGmOmACux+iTmi8huY8xsYLOILAHmA/8xxuwFUrASgUdw\nMv7ngCDgU0dWPiQi51VYtYOT8Z/zEjzodJAz8YvICmNMrDFmF1AATBcP+Ubn5Ps/HfiXMWYaVifx\nhIrX6F7GmA+BQUAzY8xhYCZWMhMReVNElhpjrjPG7MMqI3+3fdGer6r4gRlABDDP8dnNF5G+dsVb\nmhOxl+b0KTgdLKaUUg2YzjGslFINmCYBpZRqwDQJKKVUA6ZJQCmlGjBNAkop1YBpElBKqQZMk4BS\nSjVgmgSUUqoB+/9LmW0SGCNVOgAAAABJRU5ErkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f3182bc4a10>"
       ]
      },
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYEAAAEACAYAAABVtcpZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f3182bc4fd0>"
       ]
      }
     ],
     "prompt_number": 4
    }
   ],
   "metadata": {}
  }
 ]
}